@@ -2,11 +2,39 @@
     pygments.lexers._csound_builtins
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2022 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
-# Opcodes in Csound 6.14.0 using:
+REMOVED_OPCODES = set('''
+OSCsendA
+beadsynt
+beosc
+buchla
+getrowlin
+lua_exec
+lua_iaopcall
+lua_iaopcall_off
+lua_ikopcall
+lua_ikopcall_off
+lua_iopcall
+lua_iopcall_off
+lua_opdef
+mp3scal_check
+mp3scal_load
+mp3scal_load2
+mp3scal_play
+mp3scal_play2
+pvsgendy
+socksend_k
+signalflowgraph
+sumTableFilter
+systime
+tabrowlin
+vbap1move
+'''.split())
+
+# Opcodes in Csound 6.17.0 using:
 #   python3 -c "
 #   import re
 #   from subprocess import Popen, PIPE
@@ -209,6 +237,7 @@ ampmidicurve
 ampmidid
 apoleparams
 arduinoRead
+arduinoReadF
 arduinoStart
 arduinoStop
 areson
@@ -216,6 +245,7 @@ aresonk
 atone
 atonek
 atonex
+autocorr
 babo
 balance
 balance2
@@ -223,11 +253,10 @@ bamboo
 barmodel
 bbcutm
 bbcuts
-beadsynt
-beosc
 betarand
 bexprnd
 bformdec1
+bformdec2
 bformenc1
 binit
 biquad
@@ -259,6 +288,7 @@ centroid
 ceps
 cepsinv
 chanctrl
+changed
 changed2
 chani
 chano
@@ -293,6 +323,8 @@ cmp
 cmplxprod
 cntCreate
 cntCycles
+cntDelete
+cntDelete_i
 cntRead
 cntReset
 cntState
@@ -342,6 +374,11 @@ ctrl14
 ctrl21
 ctrl7
 ctrlinit
+ctrlpreset
+ctrlprint
+ctrlprintpresets
+ctrlsave
+ctrlselect
 cuserrnd
 dam
 date
@@ -523,13 +560,13 @@ getcfg
 getcol
 getftargs
 getrow
-getrowlin
 getseed
 gogobel
 grain
 grain2
 grain3
 granule
+gtadsr
 gtf
 guiro
 harmon
@@ -776,6 +813,7 @@ lagud
 lastcycle
 lenarray
 lfo
+lfsr
 limit
 limit1
 lincos
@@ -836,14 +874,6 @@ lpreson
 lpshold
 lpsholdp
 lpslot
-lua_exec
-lua_iaopcall
-lua_iaopcall_off
-lua_ikopcall
-lua_ikopcall_off
-lua_iopcall
-lua_iopcall_off
-lua_opdef
 lufs
 mac
 maca
@@ -868,6 +898,7 @@ median
 mediank
 metro
 metro2
+metrobpm
 mfb
 midglobal
 midiarp
@@ -916,10 +947,12 @@ mp3bitrate
 mp3in
 mp3len
 mp3nchnls
+mp3out
 mp3scal
 mp3sr
 mpulse
 mrtmsg
+ms2st
 mtof
 mton
 multitap
@@ -929,6 +962,7 @@ mvclpf1
 mvclpf2
 mvclpf3
 mvclpf4
+mvmfilter
 mxadsr
 nchnls_hw
 nestedap
@@ -972,6 +1006,7 @@ oscils
 oscilx
 out
 out32
+outall
 outc
 outch
 outh
@@ -1116,6 +1151,7 @@ pvsftr
 pvsftw
 pvsfwrite
 pvsgain
+pvsgendy
 pvshift
 pvsifd
 pvsin
@@ -1279,11 +1315,15 @@ sc_lagud
 sc_phasor
 sc_trig
 scale
+scale2
 scalearray
 scanhammer
+scanmap
 scans
+scansmap
 scantable
 scanu
+scanu2
 schedkwhen
 schedkwhennamed
 schedule
@@ -1299,6 +1339,7 @@ sense
 sensekey
 seqtime
 seqtime2
+sequ
 serialBegin
 serialEnd
 serialFlush
@@ -1333,6 +1374,7 @@ sin
 sinh
 sininv
 sinsyn
+skf
 sleighbells
 slicearray
 slicearray_i
@@ -1368,12 +1410,14 @@ spat3d
 spat3di
 spat3dt
 spdist
+spf
 splitrig
 sprintf
 sprintfk
 spsend
 sqrt
 squinewave
+st2ms
 statevar
 sterrain
 stix
@@ -1414,6 +1458,7 @@ subinstrinit
 sum
 sumarray
 svfilter
+svn
 syncgrain
 syncloop
 syncphasor
@@ -1454,7 +1499,6 @@ tabmorphak
 tabmorphi
 tabplay
 tabrec
-tabrowlin
 tabsum
 tabw
 tabw_i
@@ -1486,8 +1530,12 @@ transegr
 trcross
 trfilter
 trhighest
+trigExpseg
+trigLinseg
+trigexpseg
 trigger
 trighold
+triglinseg
 trigphasor
 trigseq
 trim
@@ -1500,6 +1548,8 @@ trshift
 trsplit
 turnoff
 turnoff2
+turnoff2_i
+turnoff3
 turnon
 tvconv
 unirand
@@ -1523,6 +1573,7 @@ vbapmove
 vbapz
 vbapzmove
 vcella
+vclpf
 vco
 vco2
 vco2ft
@@ -1611,13 +1662,10 @@ window
 wrap
 writescratch
 wterrain
+wterrain2
 xadsr
 xin
 xout
-xscanmap
-xscans
-xscansmap
-xscanu
 xtratim
 xyscale
 zacl
@@ -1647,7 +1695,6 @@ DEPRECATED_OPCODES = set('''
 array
 bformdec
 bformenc
-changed
 copy2ftab
 copy2ttab
 hrtfer
@@ -1720,5 +1767,9 @@ vbap4
 vbap4move
 vbap8
 vbap8move
+xscanmap
+xscans
+xscansmap
+xscanu
 xyin
 '''.split())
